
# waylay-beta (DISABLED)

This is a sunsetting release of `waylay-beta` that is included in 
the replacement [`waylay-sdk`](https://pypi.org/project/waylay-sdk/) package.

Installing this version of `waylay-beta` has the intended effect of disabling all
the code of previous versions, making the `waylay` namespace package available for new tools.
